diff -ur nagios-plugins-1.4.16/plugins/check_smtp.c nagios-plugins-1.4.16-new/plugins/check_smtp.c
--- nagios-plugins-1.4.16/plugins/check_smtp.c	2012-06-27 12:32:47.000000000 -0500
+++ nagios-plugins-1.4.16-new/plugins/check_smtp.c	2013-02-05 11:05:22.000000000 -0600
@@ -84,6 +84,7 @@
 int eflags = 0;
 int errcode, excode;
 
+char *outbound_ip = NULL;
 int server_port = SMTP_PORT;
 char *server_address = NULL;
 char *server_expect = NULL;
@@ -179,7 +180,7 @@
 	gettimeofday (&tv, NULL);
 
 	/* try to connect to the host at the given port number */
-	result = my_tcp_connect (server_address, server_port, &sd);
+	result = my_tcp_connect_inner (server_address, server_port, &sd, outbound_ip);
 
 	if (result == STATE_OK) { /* we connected */
 
@@ -495,13 +496,16 @@
 	}
 
 	while (1) {
-		c = getopt_long (argc, argv, "+hVv46t:p:f:e:c:w:H:C:R:SD:F:A:U:P:q",
+		c = getopt_long (argc, argv, "+hVv46t:p:f:e:c:w:H:C:R:SD:F:A:U:P:qI:",
 		                 longopts, &option);
 
 		if (c == -1 || c == EOF)
 			break;
 
 		switch (c) {
+                case 'I':
+                        outbound_ip = optarg;
+                        break;
 		case 'H':									/* hostname */
 			if (is_host (optarg)) {
 				server_address = optarg;
@@ -831,6 +835,8 @@
   printf ("    %s\n", _("SMTP AUTH password"));
   printf (" %s\n", "-q, --ignore-quit-failure");
   printf ("    %s\n", _("Ignore failure when sending QUIT command to server"));
+  printf (" %s\n", "-I ADDR");
+  printf ("    %s\n", _("Establish outbound connection from local address ADDR (hostname or IP, must be bound to a local interface)"));
    
 	printf (UT_WARN_CRIT);
 
diff -ur nagios-plugins-1.4.16/plugins/netutils.c nagios-plugins-1.4.16-new/plugins/netutils.c
--- nagios-plugins-1.4.16/plugins/netutils.c	2012-06-27 12:32:47.000000000 -0500
+++ nagios-plugins-1.4.16-new/plugins/netutils.c	2013-02-05 11:01:07.000000000 -0600
@@ -155,17 +155,17 @@
 	return result;
 }
 
-
 /* opens a tcp or udp connection to a remote host or local socket */
 int
-np_net_connect (const char *host_name, int port, int *sd, int proto)
+np_net_connect_inner (const char *host_name, int port, int *sd, int proto, char *out_host)
 {
 	struct addrinfo hints;
-	struct addrinfo *r, *res;
+	struct addrinfo *r, *res, *out_res;
 	struct sockaddr_un su;
 	char port_str[6], host[MAX_HOST_ADDRESS_LENGTH];
 	size_t len;
 	int socktype, result;
+        struct sockaddr_in outbound_addr;
 
 	socktype = (proto == IPPROTO_UDP) ? SOCK_DGRAM : SOCK_STREAM;
 
@@ -194,6 +194,31 @@
 			return STATE_UNKNOWN;
 		}
 
+                if (out_host != NULL) {
+		        len = strlen (out_host);
+		        /* check for an [IPv6] address (and strip the brackets) */
+		        if (len >= 2 && out_host[0] == '[' && out_host[len - 1] == ']') {
+			        out_host++;
+			        len -= 2;
+		        }
+		        if (len >= sizeof(host))
+			        return STATE_UNKNOWN;
+		        memcpy (host, out_host, len);
+		        host[len] = '\0';
+		        result = getaddrinfo (host, NULL, &hints, &out_res);
+
+		        if (result != 0) {
+			        printf ("%s\n", gai_strerror (result));
+			        return STATE_UNKNOWN;
+		        }
+
+                        memset(&outbound_addr, 0, sizeof(outbound_addr));
+                        outbound_addr.sin_family = address_family;
+                        outbound_addr.sin_addr.s_addr = ((struct sockaddr_in *)out_res->ai_addr)->sin_addr.s_addr;
+		        freeaddrinfo (out_res);
+                }
+
+
 		r = res;
 		while (r) {
 			/* attempt to create a socket */
@@ -205,6 +230,14 @@
 				return STATE_UNKNOWN;
 			}
 
+                        if (out_host != NULL) {
+                                if (bind(*sd, &outbound_addr, sizeof(outbound_addr)) < 0) {
+                                        printf ("%s: %s\n", _("Attempt to bind to outbound IP failed"), strerror(errno));
+                                        freeaddrinfo (r);
+                                        return STATE_UNKNOWN;
+                                }
+                        }
+
 			/* attempt to open a connection */
 			result = connect (*sd, r->ai_addr, r->ai_addrlen);
 
@@ -267,6 +300,12 @@
 }
 
 int
+np_net_connect (const char *host_name, int port, int *sd, int proto)
+{
+        return np_net_connect_inner(host_name, port, sd, proto, NULL);
+}
+
+int
 send_request (int sd, int proto, const char *send_buffer, char *recv_buffer, int recv_size)
 {
 	int result = STATE_OK;
diff -ur nagios-plugins-1.4.16/plugins/netutils.h nagios-plugins-1.4.16-new/plugins/netutils.h
--- nagios-plugins-1.4.16/plugins/netutils.h	2012-06-27 12:32:47.000000000 -0500
+++ nagios-plugins-1.4.16-new/plugins/netutils.h	2013-02-05 10:26:18.000000000 -0600
@@ -56,8 +56,10 @@
   const char *sbuffer, char *rbuffer, int rsize);
 
 /* my_connect and wrapper macros */
+#define my_tcp_connect_inner(addr, port, s, ip) np_net_connect_inner(addr, port, s, IPPROTO_TCP, ip)
 #define my_tcp_connect(addr, port, s) np_net_connect(addr, port, s, IPPROTO_TCP)
 #define my_udp_connect(addr, port, s) np_net_connect(addr, port, s, IPPROTO_UDP)
+int np_net_connect_inner(const char *address, int port, int *sd, int proto, char *outbound_ip);
 int np_net_connect(const char *address, int port, int *sd, int proto);
 
 /* send_request and wrapper macros */
